[Lldb-commits] [lldb] [lldb][test] Remove home dir paths from core files used in tests (PR #201630)
Raphael Isemann via lldb-commits
lldb-commits at lists.llvm.org
Thu Jun 4 09:51:12 PDT 2026
https://github.com/Teemperor created https://github.com/llvm/llvm-project/pull/201630
Most of our core files contain paths to the source files that were used to generate the core file. LLDB probes the existence of these source files when it sees them in the core file, which on its own is not problematic as that's usually quite cheap.
Unfortunately, the paths used in most core file tests are in the form of /home/XYZ/test.c which does not exist on macOS. On some macOS machines with network drives, these file accesses cause the kernel to perform some kind of network request which is extremely slow.
The result is that the tests that inspect these core files run extremely slow on macOS. For example, the TestNetBSDCore.py and TestLinuxCore.py tests spend 95% of their runtime just probing these network paths. In the case of TestLinuxCore.py, this causes the test to run for about 1 minute where only 3.7s are actual test logic.
This patch removes all /home/* paths from our core files and replaces them with /tmp/* variations. To keep the actual binary diff minimal, I padded the paths with zeroes, so this patch effectively just sets some of the bits of the core fiiles to 0 and replaces /home/ with /tmp/.
>From be4646aae9faee0271c0b0a4de427d97630b91a1 Mon Sep 17 00:00:00 2001
From: Raphael Isemann <rise at apple.com>
Date: Thu, 4 Jun 2026 16:10:12 +0100
Subject: [PATCH] [lldb][test] Remove home dir paths from core files used in
tests
Most of our core files contain paths to the source files that
were used to generate the core file. LLDB probes the existence of these
source files when it sees them in the core file, which on its own
is not problematic as that's usually quite cheap.
Unfortunately, the paths used in most core file tests are
in the form of /home/XYZ/test.c which does not exist on macOS.
On some macOS machines with network drives, these file accesses cause
the kernel to perform some kind of network request which is extremely
slow.
The result is that the tests that inspect these core files run
extremely slow on macOS. For example, the TestNetBSDCore.py and
TestLinuxCore.py tests spend 95% of their runtime just probing these
network paths. In the case of TestLinuxCore.py, this causes the test
to run for about 1 minute where only 3.7s are actual test logic.
This patch removes all /home/* paths from our core files and replaces
them with /tmp/* variations. To keep the actual binary diff minimal,
I padded the paths with zeroes, so this patch effectively just sets
some of the bits of the core fiiles to 0 and replaces /home/ with
/tmp/.
---
.../postmortem/elf-core/TestLinuxCore.py | 4 ++--
.../postmortem/elf-core/altmain.core | Bin 40960 -> 40960 bytes
.../postmortem/elf-core/altmain.out | Bin 2330 -> 2330 bytes
.../elf-core/linux-aarch64-neon.core | Bin 32768 -> 32768 bytes
.../elf-core/linux-aarch64-pac.core | Bin 151552 -> 151552 bytes
.../postmortem/elf-core/linux-aarch64-pac.out | Bin 3256 -> 3256 bytes
.../elf-core/linux-aarch64-sve-fpsimd.core | Bin 147456 -> 147456 bytes
.../elf-core/linux-aarch64-sve-full.core | Bin 147456 -> 147456 bytes
.../postmortem/elf-core/linux-aarch64.core | Bin 24576 -> 24576 bytes
.../postmortem/elf-core/linux-aarch64.out | Bin 2840 -> 2840 bytes
.../elf-core/linux-fpr_sse_i386.core | Bin 32768 -> 32768 bytes
.../elf-core/linux-fpr_sse_x86_64.core | Bin 40960 -> 40960 bytes
.../postmortem/elf-core/linux-i386.core | Bin 28672 -> 28672 bytes
.../postmortem/elf-core/linux-i386.out | Bin 1971 -> 1971 bytes
.../elf-core/linux-loongarch64.core | Bin 36044 -> 36044 bytes
.../postmortem/elf-core/linux-loongarch64.out | Bin 2944 -> 2944 bytes
.../postmortem/elf-core/linux-ppc64le.out | Bin 3128 -> 3128 bytes
.../elf-core/linux-riscv64.gpr_fpr.core | Bin 20480 -> 20480 bytes
.../elf-core/linux-riscv64.gpr_fpr.out | Bin 3480 -> 3480 bytes
.../elf-core/linux-riscv64.gpr_only.core | Bin 28672 -> 28672 bytes
.../elf-core/linux-riscv64.gpr_only.out | Bin 3520 -> 3520 bytes
.../postmortem/elf-core/linux-s390x.out | Bin 2824 -> 2824 bytes
.../postmortem/elf-core/linux-x86_64.out | Bin 2575 -> 2575 bytes
.../postmortem/netbsd-core/1lwp_SIGSEGV.amd64 | Bin 13616 -> 13616 bytes
.../netbsd-core/1lwp_SIGSEGV.amd64.core | Bin 101872 -> 101872 bytes
.../netbsd-core/2lwp_process_SIGSEGV.amd64 | Bin 16344 -> 16344 bytes
.../2lwp_process_SIGSEGV.amd64.core | Bin 121216 -> 121216 bytes
.../netbsd-core/2lwp_t2_SIGSEGV.amd64 | Bin 15456 -> 15456 bytes
.../netbsd-core/2lwp_t2_SIGSEGV.amd64.core | Bin 121192 -> 121192 bytes
29 files changed, 2 insertions(+), 2 deletions(-)
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/TestLinuxCore.py b/lldb/test/API/functionalities/postmortem/elf-core/TestLinuxCore.py
index fe888c670cd6b..3907542f2f182 100644
--- a/lldb/test/API/functionalities/postmortem/elf-core/TestLinuxCore.py
+++ b/lldb/test/API/functionalities/postmortem/elf-core/TestLinuxCore.py
@@ -333,9 +333,9 @@ def test_object_map(self):
lldbutil.mkdir_p(os.path.dirname(executable))
shutil.copyfile("linux-i386.out", executable)
# Replace the original module path at /home/labath/test and load the core
self.runCmd(
- "settings set target.object-map /home/labath/test {}".format(
+ "settings set target.object-map /tmp/core {}".format(
tmp_object_map_root
)
)
@@ -333,9 +333,9 @@ def test_object_map(self):
lldbutil.mkdir_p(os.path.dirname(executable))
shutil.copyfile("linux-i386.out", executable)
- # Replace the original module path at /home/labath/test and load the core
+ # Replace the original module path at /tmp/core and load the core
self.runCmd(
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/altmain.core b/lldb/test/API/functionalities/postmortem/elf-core/altmain.core
index 423413070c7a32c96e365dd0ba9b81fcb7291f5b..65bb911b8efb43963e00762f7d0452e7298e0893 100644
GIT binary patch
delta 53
zcmZoTz|?SnX~R-hj*{F0{p9?j)X5JS#V1c-X4!m#RoDwIx>-^3z4&GWNj;851qJ{g
CVG}z5
delta 49
vcmZoTz|?SnX~R<1$@;=#Z2F0M`K2YB53)*mA at da_--~ZHkd)$BRA2xAqo5ES
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/altmain.out b/lldb/test/API/functionalities/postmortem/elf-core/altmain.out
index 2fddf3e8f8037c9c191e401cca604ac695208abf..1a230ef2a0e28a63e6bc1ad4f73d52ee75ea5683 100755
GIT binary patch
delta 35
fcmbOwG)riMKC at U!Zh?Mseo-m|3fSz*e3cado8AXc
delta 35
qcmbOwG)riMKC at Uxer~FMPGVAGNrrw-W?pH9ZgPH6>SkBwtE>Rrv<#mB
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-neon.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-neon.core
index 19364be3b70a27ad5fd306a7a72de85858ca417d..6c90c6f19b7c45cb598bee345401a39d84ed7c0e 100644
GIT binary patch
delta 31
ncmZo at U}|V!+HjPWqa?RLKRLfBb at E5X;K>u1SvIS%-Khisyz2|(
delta 30
mcmZo at U}|V!+HjP0azeex<O^kX?D{3C#U*<Ao8{OZRRRFF=nLTh
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-pac.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-pac.core
index 3e89a36ec830e2396cf6ec25d1b12f320561ab9a..fc6efeca0f11f5c7d956940e6e86f11cf2194cd6 100644
GIT binary patch
delta 38
ucmZozz}c{XbHh<qj*{F0{p9?j)QO71lP55<G(TZ&f5OVR{Ru0Rj28eJ{SDFp
delta 48
zcmZozz}c{XbHh<q$&CEmRQ>$i#LOc7g2ZIq<ou#k{Y1U|(vs$TtnK$$8MohKWm572
E0L3*C{r~^~
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-pac.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-pac.out
index 6df8e1c9e3025d900e5df944441b5db4d85a5839..b439161a94e181e50cf992caeaf532ee125a576c 100755
GIT binary patch
delta 29
lcmdlXxkGZp9~O?1+yedN{G!y!jhyC_CveJbj%1Bz2LP`<3Yh=^
delta 105
zcmXBJF%CdL5J1s}ID<oM<_t=mQlY>avFsR`9b8MIaX1B``FY8|(knggs2Z3Mm>MUr
zvrOQ9*M2b_ZZ9 at 6i|~k6|D_ldvLc6movk{a8}HO%fQ5q+iy{H~-dGkq%eYP+c@!un
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-sve-fpsimd.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-sve-fpsimd.core
index c58c8fa97795b106e0bcae31800a0ba82dbd13cc..3a7dcd5d426a6f96722acec10bdf36ff93b244e2 100644
GIT binary patch
delta 39
pcmZo@;B08%+;Egtpd`0IKRLfBl>rKxud=pZWo6ucm6b``3IO&03w;0p
delta 39
ucmZo@;B08%+;EgtAR|9FRX;yBF|$ZNQ7^x=r1>gq`&CxP?N?cuw5<RqI}Ta^
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-sve-full.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64-sve-full.core
index 6f408e4fea01a234464cbe8241364d49f6d406c1..f1e48495cd77bdb8b2f07a4049d9115b280c7b06 100644
GIT binary patch
delta 39
vcmZo@;B08%+;EhYqa?RLKRLfBb at D+*>B$qAS(@Llw!dLz-2R4 at NyG{OCyEX|
delta 38
ucmZo@;B08%+;EhYD<eNQRX;yBF|%m;LwhF4<`=B(FIXA3zhGsOumS)cLk>0o
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64.core
index f9211cab27789ce9d69ab2df7608857254193912..2e25ae48b45c710d75545b1b9e2bf63ca522228b 100644
GIT binary patch
delta 44
qcmZoTz}Rqral=wpj*{F0{p9?j)X5(iqbE;bX4%Zc)*Xo~ng{@Z)DYMJ
delta 45
ocmZoTz}Rqral=y9$>AbVZ2F0M`K2YBS=lB<g82LpJ_8H at 0AsQYcK`qY
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-aarch64.out
index 78304a97a826f3bae6577099f6257347d782022c..4fc20aec658d552aab6acaf4a6e9e348858cb562 100755
GIT binary patch
delta 29
lcmbOsHbZPfI15KfZh?Mseo^Y=hwSE)Kd{Se-o%o|1^}Sp3dR5c
delta 103
zcmbOsHbZPfI7?JUer~FMer{rBkzQ6}Sz>02etCXTwth}dN)nJL%hfF?%FjwoE`f-Y
zq!yRxI|g{_r<LX<mt^MWCFW$7WTqDD7vvY0<mMNZq~_|U=A`K+=NF}J-pG>91_0RK
BCi?&Y
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-fpr_sse_i386.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-fpr_sse_i386.core
index b0fdaf67ca4f5f2e31ee6bbe53501941a5e10b32..deddab1a36b2bd0c3237bd734e732f296a781d02 100644
GIT binary patch
delta 44
rcmZo at U}|V!+EB^NQIcDrpPXNmI at ypZeX@Zv%jP%C^QsY|3t963Uz-pN
delta 45
ncmZo at U}|V!+EB?nd4X^`n|`8Rerd_(XUt2gL41A)p8*B{a at Y-r
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-fpr_sse_x86_64.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-fpr_sse_x86_64.core
index 5fb39ee115b2a6fbf04dbfddf5e78c3fb2544c37..053ea0a5acea3046f45b812bf018508ff516d9fb 100644
GIT binary patch
delta 52
ycmZoTz|?SnX~R-hj*{F0{p9?j)X5u}(<e`0X4x#kR^*8+nm0*6V6#BL2Y&zw3=>`e
delta 41
mcmZoTz|?SnX~R<1$%-QBZ2F0M`K2YBh1e=Qk@?^KIRgMN?G94_
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-i386.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-i386.core
index f8deff474d1fa0e8e923a0d3f8f0e52b18f3af9d..256c9b54529112c0dba09236f7e54ef77eb2e2ce 100644
GIT binary patch
delta 69
tcmZp8z}WDBaYH4uSV?YyesX?Ms(zwgerX8<6m0Hi4$6_oE(cS?008FM5TyVB
delta 69
ycmZp8z}WDBaYH4uSVn$ss(wylQesJleo1O^iGHG9erd_(e&(PYdF*lwFaQ9K)E2n_
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-i386.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-i386.out
index 3cdd4eeca10306ffe8fde7e09eff14bae8a7add9..688b5fdf99dbba1e84938a82d358884889aa004e 100755
GIT binary patch
delta 29
fcmdnYznOo-HfDj6+yedN{GwC_DA;_A`7JX5jxGq3
delta 29
lcmdnYznOo-HfDj0{M=OioW!KWk_`Ql)Z&uO$C%$T0|2Sy3!MM}
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-loongarch64.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-loongarch64.core
index 8738950b8e08dcc474939d405c459cce986d66c0..cec81075588c0b38323583c063c05a8fd915877c 100644
GIT binary patch
delta 31
ncmX>zlj+P%rVX-e93{C0`pNl4sgpl41y6p!%CfnJEuakm$3+Y?
delta 25
hcmX>zlj+P%rVX-elPz5X+4K|j@=HrLm#{^&0RVhq2`c~q
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-loongarch64.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-loongarch64.out
index ea3c61ac5bae7cc26b3afa886831d723036e021a..ddfb2878df79256b78043e83ff4240c410401213 100755
GIT binary patch
delta 29
kcmZn=ZxG*L$;wfZTcDquUz9qTk;8tn0Ef=zHLO=y0f{CFJpcdz
delta 94
zcmZn=ZxG*L$?BVtpPQ<mlUbUWr(aN%pOu<iqMwsfmaB{4q$KH=q!yRxI|g{_r<LX<
pmt^MWCFW$7WTqDD7vvY0<mMNZq~_|U=A`LPwq;e at yoU7(D*$yFBPaj>
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-ppc64le.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-ppc64le.out
index 05c69fd291b7446cbf114f8279bb510d3214189d..0c55882862c6b3bf6e76d0cabffc72eebf836755 100755
GIT binary patch
delta 29
lcmdlXu|r}*J1a*?Zh?Mseo^Y=jU4Wi4{*qA{>19W1^}v=3l0DP
delta 119
zcmW;Cu?@mN3`XH9%#bCJ$DpO7MCS5`Gx43Hvm=oSSO<wFYq0?l-P5PH^;`dbb&qTX
z#EK`^q2ao6Vb2mw7i*KxoIt9>jrN-O4yW at P+3FvCkpKleXk2OvvC1kT`!$<Ku@)!<
N9goQxKHu(i_yGe2F5UnD
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_fpr.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_fpr.core
index 7187b4000c56dc8ca74aec484310746a0fdd1e9c..8071207b1a36936866269e5aee39247f60bbeb65 100644
GIT binary patch
delta 32
hcmZozz}T>Wal=zq!IInp{p9?jR0bH>{Ed~%3jnY`2^jzY
delta 32
ncmZozz}T>Wal=zq!HoReRQ=-2g4EO${Y1U|(vr>JSh>6a&;JZq
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_fpr.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_fpr.out
index 0e4e06dfe6de0f019ea8635f0ad271eeaa1a4bdc..8d80b62e6c16c1453080657932e030fddc6bcea9 100755
GIT binary patch
delta 24
gcmbOsJwtlKSyqmc+yedN{G!x}AJsSiVV%Pc0D3zL8UO$Q
delta 27
jcmbOsJwtlKSyt|h{M=Oi;>?27)Rc)IRW|=&ox=_Qm?#TF
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_only.core b/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_only.core
index 63265a5db123d9ebc699a927d7477a264b558e91..9f7efd23b854cd6f92abcb9c8e4628c2212ab978 100644
GIT binary patch
delta 50
rcmZp8z}WDBaRVzGM at ephesX?M>SjT<_nH$8ST-5FwHJm7G9Ul|$5IZU
delta 50
rcmZp8z}WDBaRVzGS4Mtrs(zwgerd^OLALjroB!#*w--hTGQa=;-mee|
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_only.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-riscv64.gpr_only.out
index 908d61bb54caaac5764fa2e60ad14bdcd9ed2c30..f9fe4c2c417f71b7c7a049fb3e03e6966369d4d7 100755
GIT binary patch
delta 33
ncmX>geL#A{7FLdu+yedN{G!y!2RZF0U*I$VV#&=eY&Glv;|UCo
delta 125
zcmX>geL#A{7S`O1{M=Oi#N5=Ps+`Ki?EEtQAkSb|eIo-SV?9G7JwxO8qRistGBXq1
zoXot^3jLg%vRvJQqWrAX<Psn!B}u;|wYWszF~Czltu!yWBr`uRF(<PmGqqU1AiuaI
bH@~PPHCI11CrvjwzbJL$N9D~fY&GlvFH0^T
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-s390x.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-s390x.out
index 640fbdc257d9cece577e91d203ac9173fb2d8f15..493b848d69fb793e849851de247c7eb6adcb305c 100755
GIT binary patch
delta 29
lcmeAW>k!+pj)kKnw?IERzbJL`MRu#n57 at OgOS8UZ1puRU3f}+#
delta 140
zcmeAW>k!+pj-@^$KQ~psv^+I4JuxpuKPRUw7fk48q$Z~5m*nT?6a)DwN%{qe$=QkN
zsm1yMl_eSZd0 at ff(#(=n{gTw;68*H&yyTM1{Jg}R%#uu?s)GFDlHB~Fl2o8^nR%rZ
iy2<%PsSNIZp$g6lCVCcnrV2&|hNcE)n{`=lvjPCS;4;bp
diff --git a/lldb/test/API/functionalities/postmortem/elf-core/linux-x86_64.out b/lldb/test/API/functionalities/postmortem/elf-core/linux-x86_64.out
index 842402fd519d285dd21fd5b1a4040446121a161c..c78a43cb99b22ece8f95b0be26e994dca3141393 100755
GIT binary patch
delta 29
fcmeAd=@;4H#UfCWTcDquUzExK1)HN-wz2{MdpHM4
delta 29
kcmeAd=@;4H#UhZApPQ<mlbDoPlA&LcT3oU at ie)P+0G93wQvd(}
diff --git a/lldb/test/API/functionalities/postmortem/netbsd-core/1lwp_SIGSEGV.amd64 b/lldb/test/API/functionalities/postmortem/netbsd-core/1lwp_SIGSEGV.amd64
index 56fa077bd6a9d9f25201eed51b2fcf764bacf48d..ed0d515a8e87dc61833c587611c56e59fca7ecb7 100755
GIT binary patch
delta 25
hcmdmxwIOT64^@tm+yedN{G!y!8wGqe`=~wP0|1xb3hDp=
delta 96
zcmW;9!3lsc3;@6l+(LhnL3}zvTcfr#i8N7gtAaDRgHOfJ!PQh#ecEvqLZC$opOEuG
r{Z=GlurHGbL$#ma6cy&3gGFJNqs8x=sF4&y0!H&X^+5_=Lw7eXmp&&p
diff --git a/lldb/test/API/functionalities/postmortem/netbsd-core/1lwp_SIGSEGV.amd64.core b/lldb/test/API/functionalities/postmortem/netbsd-core/1lwp_SIGSEGV.amd64.core
index d2d405004555a7d08fe1eb361de33a84ce397b1c..65c67719ffc6668e864265a8084ea76f2104065f 100644
GIT binary patch
delta 57
zcmew`o9)AFwhaf_I7)I0^po?8Qa3w3;b)niV8F=Ie1~iM9WKVB6{vFCceFEFumJ$9
CEEabF
delta 135
zcmew`o9)AFwhaf_rvGVYl#?q+OwLYBPc7CDs4U6I&(qJzNl7X$%`8dPFG(#fnXb{n
qsLrTA-9VmEVzcX$+04 at u3>aCO?{ICu!^L>Cf-EDp?`UVVU;_XKjWWpq
diff --git a/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_process_SIGSEGV.amd64 b/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_process_SIGSEGV.amd64
index 32a49852215a752fac1582053b51a68c92ce4933..aa4c028981938c7a63224c202bca1b7f5458bfcc 100755
GIT binary patch
delta 25
hcmcanf1`fGFCC7O+yedN{G!y!4+VTS`{{NG0RW`G3s3+6
delta 96
zcmcanf1`fGFP-3w{M=Oi-1PjSyh{C?oU&Zqf};Ga)Z`K%CnZV0B(=B%Oe7~3rxxp{
tmF6XvWaj53=46&+0{I2`#U;7<MJ1`Z`gy4(NyRC;$@xX8n|*b=g#gC$Cu{%!
diff --git a/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_process_SIGSEGV.amd64.core b/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_process_SIGSEGV.amd64.core
index 2dbb299bbfb0a7aefd1534fad97d24cc2ea8e463..e69906ab24dd98ac63b67795d848c3063b3d808e 100644
GIT binary patch
delta 52
wcmZqJ%-*n>eM2TYM at ephesX?M>Sje9ewOA2?(GfSj4KbL3U7C~%;>-d0Pn34>i_@%
delta 130
zcmZqJ%-*n>eM2Vu^q$L%a&iTU$=QkNsm1yMl_eSZdHOjyDM`hpnI)<EC8@<F(|25E
kRA<zm-q6KpvDrYUnz^}wdwT;n<I2Ni>E7;enbCm_0N2|wHvj+t
diff --git a/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_t2_SIGSEGV.amd64 b/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_t2_SIGSEGV.amd64
index d304de160f054f204c22ba80abee1935cf7df0f1..2f92b9fb6844cb7b633b7440db93e0c8aa83b12c 100755
GIT binary patch
delta 25
hcmaD*@t|VEMlFt#+yedN{G!y!7X^GavuZ~R0sx&F3VZ+n
delta 96
zcmW;9K at LDL5CFi75BLUY_A#z5)h;UCu5_31E8;_*qH&pI-s3&4yXj^o1e!Rf6Jp%S
rteF>dTH*#a2lP+;7W)4<8bprL$aQR1vfkWdHl#&O1{YWw;FtB)qA
diff --git a/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_t2_SIGSEGV.amd64.core b/lldb/test/API/functionalities/postmortem/netbsd-core/2lwp_t2_SIGSEGV.amd64.core
index 5f68687c56e5df1282db8405a2337b32a42e6c74..707cea15018cb7e0357efd8133a0be62ae4e2683 100644
GIT binary patch
delta 60
zcmaE{iT%YU_6?cr>?OGc`pNl4lQ-7tZ(pFq_>j4|fqQ!cH{-;^m{Qv{E;Bl?0RROF
B7&8C>
delta 168
zcmaE{iT%YU_6?cr)AKJg%E=WZCTAz6rxxo6RF-7q=jrF<q$CxWW|pMtm!uY#OrL$3
zQC&h`Pv0n~ydb{BC_dQJJ=oPfOfNAv#mr>;L?y;K%*_ql+Z(tUCmyDjf!j4MGdi#V
E0QdVnB>(^b
More information about the lldb-commits
mailing list